--[[
********************************
Licence: GPL
(c) msl 2012/05/04
Thx Stefan Dittforth for Exifmodule
v 0.1
********************************
@title Exif User Comment
@param l 1=Deutsch 2=English
@default l 1
]]

--DEFINITIONS
require "EXIFModule"

if l < 0 or l > 2 then l = 1 end

lng = l

if lng == 2 then
    tags = {"nature", "architecture", "vacation", "people", "event", "landscape", "panorama", "HDR"}
else
    tags = {"Natur", "Architektur", "Urlaub", "Leute", "Ereignis", "Landschaft", "Panorama", "HDR"}
end
user_tags = {}
tag_file_path = "A/CHDK/SCRIPTS/tags.txt"
index = 1
jpg = ""
msg_no_image     = {"Kein Bild ausgewhlt.", "No image selected."}
msg_canceled     = {"abgebrochen", "canceled"}
msg_tag_write    = {"Tag wurde geschrieben.", "Tag was written."}
msg_create_file  = {"Datei tag.txt erstellt.", "File tag.txt created."}
menu_header      = "[\18] [\27] [\26] [SET] [MENU]"
menu_description = "Tag Add Pic  Exif  End"

--FUNCTIONS
function create_file(tag_file, tag_array) -- input standard tag array in new text file
    local file = io.open(tag_file, "wb")
    for i=1, #tag_array do
        file:write(tag_array[i].."\n")
    end
    file:close()
end

function read_file(tag_file) -- input text file, output array
    local tags = {}
    if os.stat(tag_file) then
        local file = io.open(tag_file)
        local i = 0
        for line in file:lines(tag_file) do
            i = i + 1
            tags[i] = line
        end
        file:close()
    end
    return tags
end

function append_tag(tag_file) -- input text file, append a string in text file
    local str=textbox()
    if str == nil then
        cls()
        print(msg_canceled[lng])
        console_redraw()
        sleep(1000)
    else
        local file = io.open(tag_file, "a+b")
        file:write(str.."\n")
        file:close()
    end
end

function select_file() -- select an image file for exif tagging
    local img_file = file_browser("A/DCIM")
    if img_file == nil then
        img_file = ""
        cls()
        print(msg_canceled[lng])
        console_redraw()
        sleep(1000)
    end
    return img_file
end

function check_jpg(str) -- check if jpg file
    local ret = false
    if os.stat(str) then
        local res = string.sub(str,string.len(str)-2)
        res = string.upper(res)
        if res == "JPG" then ret = true end
    end
    return ret
end

function write_tag(JpgFile, TagText) -- write user comment exif tag, requires exifmodule
    local P = JPEGImage
    P:new(JpgFile)
    P:SetUserComment(TagText)
    cls()
    print(msg_tag_write[lng])
    console_redraw()
    sleep(1000)
end

function restore()
    set_console_autoredraw(1)
    cls()
end

--MAIN
if not os.stat(tag_file_path) then
    create_file(tag_file_path, tags)
    print(msg_create_file[lng])
    sleep(2000)
end
user_tags = read_file(tag_file_path)
set_console_autoredraw(0)
while true do
    cls()
    print(menu_header)
    print(menu_description)
    print("-------------------------")
    print(string.sub(user_tags[index], 1, 25))
    if check_jpg(jpg) then
        print(string.sub(jpg,string.len(jpg)-11))
    else
        print(msg_no_image[lng])
    end
    console_redraw()
    wait_click(0)
    if     is_pressed("set") then
        if check_jpg(jpg) then write_tag(jpg, user_tags[index]) end
    elseif is_pressed("right") then
        jpg = select_file()
    elseif is_pressed("left") then
        append_tag(tag_file_path)
        user_tags = read_file(tag_file_path)
    elseif is_pressed("up") then
        index = index + 1
        if index > #user_tags then index = 1 end
    elseif is_pressed("down") then
        index = index - 1
        if index < 1 then index = #user_tags end
    elseif is_pressed("menu") then
        restore()
        break
    end
end